@@ -1,4 +1,6 @@
 # encoding: utf-8
+from bzrlib import remote
+from errno import EPIPE
 import os
 import sys
 import platform
@@ -6,13 +8,14 @@ import time
 import socket
 import uuid
 from emq.client.constants import THRIFT_PROTOCOL_MAP, DEFAULT_SECURE_SERVICE_ENDPOINT, QUEUE_SERVICE_PATH, \
-  DEFAULT_CLIENT_TIMEOUT, DEFAULT_CLIENT_CONN_TIMEOUT, MESSAGE_SERVICE_PATH
+  DEFAULT_CLIENT_TIMEOUT, DEFAULT_CLIENT_CONN_TIMEOUT, MESSAGE_SERVICE_PATH, STATISTICS_SERVICE_PATH
 from emq.client.requestchecker import RequestChecker
 from emq.client.thttpclient import THttpClient
 from emq.common.constants import ERROR_BACKOFF, MAX_RETRY, ERROR_RETRY_TYPE
 from emq.common.ttypes import Version, GalaxyEmqServiceException
 from emq.message import MessageService
 from emq.queue import QueueService
+from emq.statistics import StatisticsService
 from rpc.common.ttypes import ThriftProtocol
 
 
@@ -41,6 +44,12 @@ class ClientFactory:
     client = self.get_client(MessageService.Client, url, timeout)
     return RetryableClient(client, is_retry, max_retry)
 
+  def statistics_client(self, endpoint=DEFAULT_SECURE_SERVICE_ENDPOINT,
+                     timeout=DEFAULT_CLIENT_CONN_TIMEOUT, is_retry=False, max_retry=MAX_RETRY):
+    url = endpoint + STATISTICS_SERVICE_PATH
+    client = self.get_client(StatisticsService.Client, url, timeout)
+    return RetryableClient(client, is_retry, max_retry)
+
   def get_client(self, clazz, url, timeout):
     return ThreadSafeClient(clazz, self._credential, url, timeout, self._agent, self._protocol)
 
@@ -72,7 +81,8 @@ class RetryableClient:
             retry += 1
           else:
             raise se
-
+        except socket.error:
+          break
     return __call_with_retries
 
   def __get_error_retry_type(self, errorCode, item):
