@@ -12,10 +12,12 @@ def datum_scan_iter(table_client, scan):
       # throttling the request
       sleep(0.5 * (1 << (retry - 1)))
     result = table_client.scan(scan)
-    terminated = result.nextStartKey is None
+    terminated = result.nextStartKey is None and result.nextSplitIndex == -1
     records = result.records
     scan.startKey = result.nextStartKey
-    if not terminated and len(records) < scan.limit:
+    if result.nextSplitIndex > 0:
+      scan.splitIndex = result.nextSplitIndex
+    if not terminated and len(records) < scan.limit and result.throttled:
       retry += 1
     else:
       retry = 0
